@@ -41,7 +41,7 @@ targetLangs = []
 
 # Diretório fonte
 
-sourceDir = '_'.join(sourceLang.split('-')).lower()
+sourceDir = ''
 
 # Preservação da sintaxe Markdown DocFX
 
@@ -191,12 +191,12 @@ def root():
     global sourceLang
     global targetLangs
     global workTree
+    global sourceDir
     init()
 
     try:
         with open(os.path.expanduser('~') + '/' + 'tradocs.config.json', 'r') as file:
             configs = json.load(file)
-        print(configs)
         apiTradKey = configs['TRANSLATOR_KEY']
         sourceLang = configs['SOURCE']
         targetLangs = configs['TARGET']
@@ -212,6 +212,8 @@ def root():
         }
         with open(os.path.expanduser('~') + '/' + 'tradocs.config.json', 'w+') as file:
             json.dump(configs, file)
+    
+    sourceDir = '_'.join(sourceLang.split('-')).lower()
 
     if sourceDir not in os.listdir():
         PrRed('\nThe directory "' + sourceDir + '" for source files has not been found!')
@@ -240,8 +242,14 @@ def root():
     workTree = [n.a_blob.path for n in allModified if n.a_blob.path.split('/')[0] == '_'.join(sourceLang.split('-')).lower()] + untrackedSrc
 
 @root.command()
+@click.option('-k', '--key', type=str)
+@click.option('-s', '--source', type=str)
+@click.option('-t', '--target', type=list)
 def config():
     """Show and set configuration"""
+    print(key)
+    print(source)
+    print(target)
     exit()
 
 @root.command()
